==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/NotificationHubPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * NotificationHub properties.
 * @property admCredential Description of a NotificationHub AdmCredential.
 * @property apnsCredential Description of a NotificationHub ApnsCredential.
 * @property baiduCredential Description of a NotificationHub BaiduCredential.
 * @property browserCredential Description of a NotificationHub BrowserCredential.
 * @property gcmCredential Description of a NotificationHub GcmCredential.
 * @property mpnsCredential Description of a NotificationHub MpnsCredential.
 * @property name Gets or sets the NotificationHub name.
 * @property registrationTtl Gets or sets the RegistrationTtl of the created NotificationHub
 * @property wnsCredential Description of a NotificationHub WnsCredential.
 * @property xiaomiCredential Description of a NotificationHub XiaomiCredential.
 */
public data class NotificationHubPropertiesArgs(
    public val admCredential: Output<AdmCredentialArgs>? = null,
    public val apnsCredential: Output<ApnsCredentialArgs>? = null,
    public val baiduCredential: Output<BaiduCredentialArgs>? = null,
    public val browserCredential: Output<BrowserCredentialArgs>? = null,
    public val gcmCredential: Output<GcmCredentialArgs>? = null,
    public val mpnsCredential: Output<MpnsCredentialArgs>? = null,
    public val name: Output<String>? = null,
    public val registrationTtl: Output<String>? = null,
    public val wnsCredential: Output<WnsCredentialArgs>? = null,
    public val xiaomiCredential: Output<XiaomiCredentialArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs =
        com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs.builder()
            .admCredential(admCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .apnsCredential(apnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .baiduCredential(baiduCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .browserCredential(browserCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gcmCredential(gcmCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mpnsCredential(mpnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .registrationTtl(registrationTtl?.applyValue({ args0 -> args0 }))
            .wnsCredential(wnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .xiaomiCredential(
                xiaomiCredential?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [NotificationHubPropertiesArgs].
 */
@PulumiTagMarker
public class NotificationHubPropertiesArgsBuilder internal constructor() {
    private var admCredential: Output<AdmCredentialArgs>? = null

    private var apnsCredential: Output<ApnsCredentialArgs>? = null

    private var baiduCredential: Output<BaiduCredentialArgs>? = null

    private var browserCredential: Output<BrowserCredentialArgs>? = null

    private var gcmCredential: Output<GcmCredentialArgs>? = null

    private var mpnsCredential: Output<MpnsCredentialArgs>? = null

    private var name: Output<String>? = null

    private var registrationTtl: Output<String>? = null

    private var wnsCredential: Output<WnsCredentialArgs>? = null

    private var xiaomiCredential: Output<XiaomiCredentialArgs>? = null

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("eymjwmpkcnqpolpd")
    public suspend fun admCredential(`value`: Output<AdmCredentialArgs>) {
        this.admCredential = value
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("boycapgiorhdayed")
    public suspend fun apnsCredential(`value`: Output<ApnsCredentialArgs>) {
        this.apnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("cxdhadbsjdakllqu")
    public suspend fun baiduCredential(`value`: Output<BaiduCredentialArgs>) {
        this.baiduCredential = value
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("bwlkdfphomtxkehi")
    public suspend fun browserCredential(`value`: Output<BrowserCredentialArgs>) {
        this.browserCredential = value
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("lscaywudforngtpo")
    public suspend fun gcmCredential(`value`: Output<GcmCredentialArgs>) {
        this.gcmCredential = value
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("kpwehqavnpkoaaqx")
    public suspend fun mpnsCredential(`value`: Output<MpnsCredentialArgs>) {
        this.mpnsCredential = value
    }

    /**
     * @param value Gets or sets the NotificationHub name.
     */
    @JvmName("humhqdtdpuayersh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the RegistrationTtl of the created NotificationHub
     */
    @JvmName("dcittdsslpfcbgqd")
    public suspend fun registrationTtl(`value`: Output<String>) {
        this.registrationTtl = value
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("mjllnlswuyajppxy")
    public suspend fun wnsCredential(`value`: Output<WnsCredentialArgs>) {
        this.wnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("sohivksayhwwfxlj")
    public suspend fun xiaomiCredential(`value`: Output<XiaomiCredentialArgs>) {
        this.xiaomiCredential = value
    }

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("qftbvhukmwjhwybv")
    public suspend fun admCredential(`value`: AdmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.admCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub AdmCredential.
     */
    @JvmName("piarwqqqboskjixu")
    public suspend fun admCredential(argument: suspend AdmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = AdmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.admCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("kmgscklsdygcxdln")
    public suspend fun apnsCredential(`value`: ApnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub ApnsCredential.
     */
    @JvmName("sqoonurpsgtmgfyy")
    public suspend fun apnsCredential(argument: suspend ApnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = ApnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("fywvnkflobmfdklo")
    public suspend fun baiduCredential(`value`: BaiduCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baiduCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BaiduCredential.
     */
    @JvmName("ufwrcfphfjxwyoia")
    public suspend fun baiduCredential(argument: suspend BaiduCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BaiduCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baiduCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("sraftlcrsnjhwtan")
    public suspend fun browserCredential(`value`: BrowserCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.browserCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BrowserCredential.
     */
    @JvmName("leprcmfnrtjqxash")
    public suspend fun browserCredential(argument: suspend BrowserCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BrowserCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.browserCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("fxhjdiuwumigjwgv")
    public suspend fun gcmCredential(`value`: GcmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gcmCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub GcmCredential.
     */
    @JvmName("dkcmxnfgbqbthqis")
    public suspend fun gcmCredential(argument: suspend GcmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = GcmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gcmCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("btkcqxutmdqyqxxu")
    public suspend fun mpnsCredential(`value`: MpnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mpnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub MpnsCredential.
     */
    @JvmName("plvenpwlqerqslyh")
    public suspend fun mpnsCredential(argument: suspend MpnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = MpnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.mpnsCredential = mapped
    }

    /**
     * @param value Gets or sets the NotificationHub name.
     */
    @JvmName("nxlkfugjoqssxpys")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the RegistrationTtl of the created NotificationHub
     */
    @JvmName("tmpbhakhsjpbsjvk")
    public suspend fun registrationTtl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationTtl = mapped
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("dndccdvdjjhafgxa")
    public suspend fun wnsCredential(`value`: WnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub WnsCredential.
     */
    @JvmName("ldgprjdrellcaywq")
    public suspend fun wnsCredential(argument: suspend WnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = WnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.wnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("lwnljbdwkifebeet")
    public suspend fun xiaomiCredential(`value`: XiaomiCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.xiaomiCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("xebinsrisbxilruh")
    public suspend fun xiaomiCredential(argument: suspend XiaomiCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = XiaomiCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.xiaomiCredential = mapped
    }

    internal fun build(): NotificationHubPropertiesArgs = NotificationHubPropertiesArgs(
        admCredential = admCredential,
        apnsCredential = apnsCredential,
        baiduCredential = baiduCredential,
        browserCredential = browserCredential,
        gcmCredential = gcmCredential,
        mpnsCredential = mpnsCredential,
        name = name,
        registrationTtl = registrationTtl,
        wnsCredential = wnsCredential,
        xiaomiCredential = xiaomiCredential,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/NotificationHubPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * NotificationHub properties.
 * @property admCredential Description of a NotificationHub AdmCredential.
 * @property apnsCredential Description of a NotificationHub ApnsCredential.
 * @property baiduCredential Description of a NotificationHub BaiduCredential.
 * @property browserCredential Description of a NotificationHub BrowserCredential.
 * @property gcmCredential Description of a NotificationHub GcmCredential.
 * @property mpnsCredential Description of a NotificationHub MpnsCredential.
 * @property name Gets or sets the NotificationHub name.
 * @property registrationTtl Gets or sets the RegistrationTtl of the created NotificationHub
 * @property wnsCredential Description of a NotificationHub WnsCredential.
 * @property xiaomiCredential Description of a NotificationHub XiaomiCredential.
 */
public data class NotificationHubPropertiesArgs(
    public val admCredential: Output<AdmCredentialArgs>? = null,
    public val apnsCredential: Output<ApnsCredentialArgs>? = null,
    public val baiduCredential: Output<BaiduCredentialArgs>? = null,
    public val browserCredential: Output<BrowserCredentialArgs>? = null,
    public val gcmCredential: Output<GcmCredentialArgs>? = null,
    public val mpnsCredential: Output<MpnsCredentialArgs>? = null,
    public val name: Output<String>? = null,
    public val registrationTtl: Output<String>? = null,
    public val wnsCredential: Output<WnsCredentialArgs>? = null,
    public val xiaomiCredential: Output<XiaomiCredentialArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs =
        com.pulumi.azurenative.notificationhubs.inputs.NotificationHubPropertiesArgs.builder()
            .admCredential(admCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .apnsCredential(apnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .baiduCredential(baiduCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .browserCredential(browserCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gcmCredential(gcmCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mpnsCredential(mpnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name?.applyValue({ args0 -> args0 }))
            .registrationTtl(registrationTtl?.applyValue({ args0 -> args0 }))
            .wnsCredential(wnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .xiaomiCredential(
                xiaomiCredential?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [NotificationHubPropertiesArgs].
 */
@PulumiTagMarker
public class NotificationHubPropertiesArgsBuilder internal constructor() {
    private var admCredential: Output<AdmCredentialArgs>? = null

    private var apnsCredential: Output<ApnsCredentialArgs>? = null

    private var baiduCredential: Output<BaiduCredentialArgs>? = null

    private var browserCredential: Output<BrowserCredentialArgs>? = null

    private var gcmCredential: Output<GcmCredentialArgs>? = null

    private var mpnsCredential: Output<MpnsCredentialArgs>? = null

    private var name: Output<String>? = null

    private var registrationTtl: Output<String>? = null

    private var wnsCredential: Output<WnsCredentialArgs>? = null

    private var xiaomiCredential: Output<XiaomiCredentialArgs>? = null

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("ntkdpmitgslmqnes")
    public suspend fun admCredential(`value`: Output<AdmCredentialArgs>) {
        this.admCredential = value
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("vynvepktsymnhrhj")
    public suspend fun apnsCredential(`value`: Output<ApnsCredentialArgs>) {
        this.apnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("tggrpbitmwcrlpvk")
    public suspend fun baiduCredential(`value`: Output<BaiduCredentialArgs>) {
        this.baiduCredential = value
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("uxdrmobjasqfhias")
    public suspend fun browserCredential(`value`: Output<BrowserCredentialArgs>) {
        this.browserCredential = value
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("ohwklgcjhpcekwqu")
    public suspend fun gcmCredential(`value`: Output<GcmCredentialArgs>) {
        this.gcmCredential = value
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("ljhrvvureqywwqxi")
    public suspend fun mpnsCredential(`value`: Output<MpnsCredentialArgs>) {
        this.mpnsCredential = value
    }

    /**
     * @param value Gets or sets the NotificationHub name.
     */
    @JvmName("oadrjedywpomklnh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the RegistrationTtl of the created NotificationHub
     */
    @JvmName("tjjbiscfbljxcjyw")
    public suspend fun registrationTtl(`value`: Output<String>) {
        this.registrationTtl = value
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("wilpxymkjngqiewj")
    public suspend fun wnsCredential(`value`: Output<WnsCredentialArgs>) {
        this.wnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("ngibnknsrhmknagk")
    public suspend fun xiaomiCredential(`value`: Output<XiaomiCredentialArgs>) {
        this.xiaomiCredential = value
    }

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("uflxfqjblirktihv")
    public suspend fun admCredential(`value`: AdmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.admCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub AdmCredential.
     */
    @JvmName("hiytvlrxjedqqvxo")
    public suspend fun admCredential(argument: suspend AdmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = AdmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.admCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("suogfewexaovmwgo")
    public suspend fun apnsCredential(`value`: ApnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub ApnsCredential.
     */
    @JvmName("jobwifimyspufsam")
    public suspend fun apnsCredential(argument: suspend ApnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = ApnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("amjbercapwjtkmqd")
    public suspend fun baiduCredential(`value`: BaiduCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baiduCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BaiduCredential.
     */
    @JvmName("vewjkqqosndhexjn")
    public suspend fun baiduCredential(argument: suspend BaiduCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BaiduCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baiduCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("msciabkssondhyev")
    public suspend fun browserCredential(`value`: BrowserCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.browserCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BrowserCredential.
     */
    @JvmName("iraujkgxgpmamjtk")
    public suspend fun browserCredential(argument: suspend BrowserCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BrowserCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.browserCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("xusyohltgguohcfg")
    public suspend fun gcmCredential(`value`: GcmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gcmCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub GcmCredential.
     */
    @JvmName("jrnjmqqbhtvyibto")
    public suspend fun gcmCredential(argument: suspend GcmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = GcmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gcmCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("gkpyvlyunkkeamqm")
    public suspend fun mpnsCredential(`value`: MpnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mpnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub MpnsCredential.
     */
    @JvmName("ucnjxvrgsxquwjxv")
    public suspend fun mpnsCredential(argument: suspend MpnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = MpnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.mpnsCredential = mapped
    }

    /**
     * @param value Gets or sets the NotificationHub name.
     */
    @JvmName("tbuhjgedtutyalcm")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the RegistrationTtl of the created NotificationHub
     */
    @JvmName("gexklhtjcgqihxpw")
    public suspend fun registrationTtl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationTtl = mapped
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("muuoqbfaclhcuipj")
    public suspend fun wnsCredential(`value`: WnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub WnsCredential.
     */
    @JvmName("urbmrtunjonrotwk")
    public suspend fun wnsCredential(argument: suspend WnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = WnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.wnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("tvcbaydtkpudfqye")
    public suspend fun xiaomiCredential(`value`: XiaomiCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.xiaomiCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("pafxdolaioojvlrx")
    public suspend fun xiaomiCredential(argument: suspend XiaomiCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = XiaomiCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.xiaomiCredential = mapped
    }

    internal fun build(): NotificationHubPropertiesArgs = NotificationHubPropertiesArgs(
        admCredential = admCredential,
        apnsCredential = apnsCredential,
        baiduCredential = baiduCredential,
        browserCredential = browserCredential,
        gcmCredential = gcmCredential,
        mpnsCredential = mpnsCredential,
        name = name,
        registrationTtl = registrationTtl,
        wnsCredential = wnsCredential,
        xiaomiCredential = xiaomiCredential,
    )
}
